# Installation

## Stable release

To install Dictionaries Addons Framework, run this command in your terminal:

```sh
uv add dictionaries-addons-framework
```

Or if you prefer to use `pip`:

```sh
pip install dictionaries-addons-framework
```

## From source

The source files for Dictionaries Addons Framework can be downloaded from the [Github repo](https://github.com/Calebh101/dictionaries_addons_framework).

You can either clone the public repository:

```sh
git clone git://github.com/Calebh101/dictionaries_addons_framework
```

Or download the [tarball](https://github.com/Calebh101/dictionaries_addons_framework/tarball/master):

```sh
curl -OJL https://github.com/Calebh101/dictionaries_addons_framework/tarball/master
```

Once you have a copy of the source, you can install it with:

```sh
cd dictionaries_addons_framework
uv pip install .
```
